aboutsummaryrefslogtreecommitdiffstats
path: root/examples/lib.rs
diff options
context:
space:
mode:
Diffstat (limited to 'examples/lib.rs')
-rw-r--r--examples/lib.rs14
1 files changed, 13 insertions, 1 deletions
diff --git a/examples/lib.rs b/examples/lib.rs
index 94c2c58..62d7ee4 100644
--- a/examples/lib.rs
+++ b/examples/lib.rs
@@ -22,7 +22,19 @@ fn main() {
)
);
- // Support extensions that are not in CommonMark.
+ // Support GFM extensions.
+ println!(
+ "{}",
+ micromark_with_options(
+ "Just a link! https://example.com.",
+ &Options {
+ constructs: Constructs::gfm(),
+ ..Options::default()
+ }
+ )
+ );
+
+ // Support other extensions that are not in CommonMark.
println!(
"{:?}",
micromark_with_options(